@@ -17,6 +17,7 @@ def get_validation_runner(
     stat_getter,
     saver,
     logger,
+    val_data_hook,
 ):
     required_data = validator.required_data
     if stat_getter:
@@ -48,6 +49,9 @@ def get_validation_runner(
         if logger:
             logger.write(engine)
 
+        if val_data_hook:
+            val_data_hook(engine, collected_data)
+
     return run_validation
 
 
